==> libreoffice-fresh-sdk-25.8.2-4-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.js <==
var servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject =
[
    [ "BaseFrame", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#abd1b1ee432faeb771618b520b411bf01", null ],
    [ "ActualSize", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a177a00cc1d60abe502608e8deb996c6a", null ],
    [ "AdjustBlue", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#aa29effc6866ac52412b0935e3d64e8da", null ],
    [ "AdjustContrast", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a1957031e0f1fc40982f2e2e95a7bf620", null ],
    [ "AdjustGreen", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#ac57f51f5c7d50c596b473324d1a22a37", null ],
    [ "AdjustLuminance", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a740ef1e3776acae7f0dbb33be613c832", null ],
    [ "AdjustRed", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a811c99705e2eaaa8efba1dcdb482b9d6", null ],
    [ "ContentProtected", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#af983cd9aa48c941eff3e415859eacdd5", null ],
    [ "ContourOutside", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#ac73395ae1755454a1d67a553695ee012", null ],
    [ "ContourPolyPolygon", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#ad619324692510567a1e6b6830e090a2a", null ],
    [ "Gamma", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a1a0cbbb118b67bb2a3f1f682c0dad85b", null ],
    [ "Graphic", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#ac9125eba7f4b60659a243b0f6d79f54b", null ],
    [ "GraphicColorMode", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a90a11382c92d602ddc4ad10ea1ed2a43", null ],
    [ "GraphicCrop", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a8671f262432054e615143c513c3227e5", null ],
    [ "GraphicFilter", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a637908bc2e821d88339c3fcd66f9a374", null ],
    [ "GraphicIsInverted", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a2cb18bea7bd13fe794ce64f6d14cf23a", null ],
    [ "GraphicURL", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a6312a2da62e2c67c90d5576502117906", null ],
    [ "HoriMirroredOnEvenPages", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a2e22196d0245f99d368f76b49362a04b", null ],
    [ "HoriMirroredOnOddPages", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#ad36ef6e77a29265a5936b2315ec76f1f", null ],
    [ "ImageMap", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a36454993846a60103ee6316b7f7131f6", null ],
    [ "SurroundContour", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#aaf8f5784d2e27826b90ce8c1c7008fb5", null ],
    [ "Transparency", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#abe2ccbd9249c78399611e42ba898e810", null ],
    [ "VertMirrored", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a4b9495b128fd6b6709da72652a99eaf5", null ]
];

==> libreoffice-fresh-sdk-26.2.0-3-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.js <==
var servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject =
[
    [ "BaseFrame", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#abd1b1ee432faeb771618b520b411bf01", null ],
    [ "ActualSize", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a177a00cc1d60abe502608e8deb996c6a", null ],
    [ "AdjustBlue", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#aa29effc6866ac52412b0935e3d64e8da", null ],
    [ "AdjustContrast", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a1957031e0f1fc40982f2e2e95a7bf620", null ],
    [ "AdjustGreen", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#ac57f51f5c7d50c596b473324d1a22a37", null ],
    [ "AdjustLuminance", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a740ef1e3776acae7f0dbb33be613c832", null ],
    [ "AdjustRed", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a811c99705e2eaaa8efba1dcdb482b9d6", null ],
    [ "ContentProtected", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#af983cd9aa48c941eff3e415859eacdd5", null ],
    [ "ContourOutside", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#ac73395ae1755454a1d67a553695ee012", null ],
    [ "ContourPolyPolygon", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#ad619324692510567a1e6b6830e090a2a", null ],
    [ "Gamma", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a1a0cbbb118b67bb2a3f1f682c0dad85b", null ],
    [ "Graphic", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#ac9125eba7f4b60659a243b0f6d79f54b", null ],
    [ "GraphicColorMode", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a90a11382c92d602ddc4ad10ea1ed2a43", null ],
    [ "GraphicCrop", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a8671f262432054e615143c513c3227e5", null ],
    [ "GraphicFilter", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a637908bc2e821d88339c3fcd66f9a374", null ],
    [ "GraphicIsInverted", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a2cb18bea7bd13fe794ce64f6d14cf23a", null ],
    [ "GraphicURL", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a6312a2da62e2c67c90d5576502117906", null ],
    [ "HoriMirroredOnEvenPages", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a2e22196d0245f99d368f76b49362a04b", null ],
    [ "HoriMirroredOnOddPages", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#ad36ef6e77a29265a5936b2315ec76f1f", null ],
    [ "ImageMap", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a36454993846a60103ee6316b7f7131f6", null ],
    [ "SurroundContour", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#aaf8f5784d2e27826b90ce8c1c7008fb5", null ],
    [ "Transparency", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#abe2ccbd9249c78399611e42ba898e810", null ],
    [ "VertMirrored", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a4b9495b128fd6b6709da72652a99eaf5", null ],
    [ "Visible", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html#a0d1d0fe42a221d48b7805c0543153169", null ]
];
